==> haskell-file-embed-0.0.10.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-file-embed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: file-embed
version: 0.0.10.1
id: file-embed-0.0.10.1-22oUm17C4yT5YwW0zZXlor
key: file-embed-0.0.10.1-22oUm17C4yT5YwW0zZXlor
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: https://github.com/snoyberg/file-embed
synopsis: Use Template Haskell to embed file contents directly.
description:
    Use Template Haskell to read a file or all the files in a
    directory, and turn them into (path, bytestring) pairs
    embedded in your Haskell code.
category: Data
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Data.FileEmbed
abi: 4c4a179f38ff188758c3889c26e3ca23
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/file-embed-0.0.10.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/file-embed-0.0.10.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/file-embed-0.0.10.1
hs-libraries: HSfile-embed-0.0.10.1-22oUm17C4yT5YwW0zZXlor
depends:
    base-4.10.0.0 bytestring-0.10.8.2 directory-1.3.0.2
    template-haskell-2.12.0.0 filepath-1.4.1.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
haddock-interfaces: /usr/share/doc/haskell-file-embed/html/file-embed.haddock
haddock-html: /usr/share/doc/haskell-file-embed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-file-embed-0.0.10-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-file-embed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: file-embed
version: 0.0.10
id: file-embed-0.0.10-6MOF39qOfbF247pdLfFPrH
key: file-embed-0.0.10-6MOF39qOfbF247pdLfFPrH
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: https://github.com/snoyberg/file-embed
synopsis: Use Template Haskell to embed file contents directly.
description:
    Use Template Haskell to read a file or all the files in a
    directory, and turn them into (path, bytestring) pairs
    embedded in your haskell code.
category: Data
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Data.FileEmbed
abi: eecfcd5f76534c28338f4b75fe5e9fdc
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/file-embed-0.0.10
library-dirs: /usr/lib/ghc-8.2.1/site-local/file-embed-0.0.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/file-embed-0.0.10
hs-libraries: HSfile-embed-0.0.10-6MOF39qOfbF247pdLfFPrH
depends:
    base-4.10.0.0 bytestring-0.10.8.2 directory-1.3.0.2
    template-haskell-2.12.0.0 filepath-1.4.1.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
haddock-interfaces: /usr/share/doc/haskell-file-embed/html/file-embed.haddock
haddock-html: /usr/share/doc/haskell-file-embed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
